===============================
compute-hyperv
===============================

Hyper-V Nova Driver

* Free software: Apache license
* Documentation: https://docs.openstack.org/nova/pike/admin/configuration/hypervisors.html
* Source: http://git.openstack.org/cgit/openstack/compute-hyperv
* Bugs: http://bugs.launchpad.net/compute-hyperv
* Release Notes: https://docs.openstack.org/releasenotes/compute-hyperv

Features
--------

* TODO
